@@ -7,80 +7,82 @@ from threading import Lock
 
 lock = Lock()
 
-html_string = \
-    r"""
-<!DOCTYPE html>
-<html lang="en">
-<head>
-    <meta charset="UTF-8"/>
-    <title>API Testka Report</title>
+_html_string_head = \
+    """
+    <!DOCTYPE html>
+    <html lang="en">
+    <head>
+        <meta charset="UTF-8"/>
+        <title>Load Density Report</title>
 
-    <style>
-      
-        body{{
-            font-size: 100%;
-        }}
+        <style>
 
-        h1{{
-            font-size: 2em;
-        }}
+            body{
+                font-size: 100%;
+            }
 
-        .main_table {{
-            margin: 0 auto;
-            border-collapse: collapse;
-            width: 75%;
-            font-size: 1.5em;
-        }}
+            h1{
+                font-size: 2em;
+            }
 
-        .success_table_head {{
-            border: 3px solid #262626;
-            background-color: aqua;
-            font-family: "Times New Roman", sans-serif;
-            text-align: center;
-        }}
+            .main_table {
+                margin: 0 auto;
+                border-collapse: collapse;
+                width: 75%;
+                font-size: 1.5em;
+            }
 
-        .failure_table_head {{
-            border: 3px solid #262626;
-            background-color: #f84c5f;
-            font-family: "Times New Roman", sans-serif;
-            text-align: center;
-        }}
+            .success_table_head {
+                border: 3px solid #262626;
+                background-color: aqua;
+                font-family: "Times New Roman", sans-serif;
+                text-align: center;
+            }
 
-        .table_data_field_title {{
-            border: 3px solid #262626;
-            padding: 0;
-            margin: 0;
-            background-color: #dedede;
-            font-family: "Times New Roman", sans-serif;
-            text-align: center;
-            width: 25%;
-        }}
+            .failure_table_head {
+                border: 3px solid #262626;
+                background-color: #f84c5f;
+                font-family: "Times New Roman", sans-serif;
+                text-align: center;
+            }
 
-        .table_data_field_text {{
-            border: 3px solid #262626;
-            padding: 0;
-            margin: 0;
-            background-color: #dedede;
-            font-family: "Times New Roman", sans-serif;
-            text-align: left;
-            width: 75%;
-        }}
+            .table_data_field_title {
+                border: 3px solid #262626;
+                padding: 0;
+                margin: 0;
+                background-color: #dedede;
+                font-family: "Times New Roman", sans-serif;
+                text-align: center;
+                width: 25%;
+            }
 
-        .text {{
-            text-align: center;
-            font-family: "Times New Roman", sans-serif;
-        }}
-    </style>
-</head>
-<body>
-<h1 class="text">
-    Test Report
-</h1>
-{success_table}
-{failure_table}
-</body>
-</html>
-""".strip()
+            .table_data_field_text {
+                border: 3px solid #262626;
+                padding: 0;
+                margin: 0;
+                background-color: #dedede;
+                font-family: "Times New Roman", sans-serif;
+                text-align: left;
+                width: 75%;
+            }
+
+            .text {
+                text-align: center;
+                font-family: "Times New Roman", sans-serif;
+            }
+        </style>
+    </head>
+    <body>
+    <h1 class="text">
+        Test Report
+    </h1>
+    """.strip()
+
+_html_string_bottom = \
+    """
+    </body>
+    </html>
+    """.strip()
 
 success_table = \
     r"""
@@ -203,57 +205,57 @@ def generate_html(html_name: str = "default_name"):
     if len(test_record.record_list) == 0 and len(test_record.error_record_list) == 0:
         raise HTMLException(html_generate_no_data_tag)
     else:
-        success = ""
+        success_list = list()
         for record_data in test_record.record_list:
-            success = "".join(
-                [
-                    success,
-                    success_table.format(
-                        status_code=record_data.get("status_code"),
-                        text=record_data.get("text"),
-                        content=str(record_data.get("content"), encoding="utf-8"),
-                        headers=record_data.get("headers"),
-                        history=record_data.get("history"),
-                        encoding=record_data.get("encoding"),
-                        cookies=record_data.get("cookies"),
-                        elapsed=record_data.get("elapsed"),
-                        request_time_sec=record_data.get("request_time_sec"),
-                        request_method=record_data.get("request_method"),
-                        request_url=record_data.get("request_url"),
-                        request_body=record_data.get("request_body"),
-                        start_time=record_data.get("start_time"),
-                        end_time=record_data.get("end_time"),
-                    )
-                ]
+            success_list.append(
+                success_table.format(
+                    status_code=record_data.get("status_code"),
+                    text=record_data.get("text"),
+                    content=str(record_data.get("content"), encoding="utf-8"),
+                    headers=record_data.get("headers"),
+                    history=record_data.get("history"),
+                    encoding=record_data.get("encoding"),
+                    cookies=record_data.get("cookies"),
+                    elapsed=record_data.get("elapsed"),
+                    request_time_sec=record_data.get("request_time_sec"),
+                    request_method=record_data.get("request_method"),
+                    request_url=record_data.get("request_url"),
+                    request_body=record_data.get("request_body"),
+                    start_time=record_data.get("start_time"),
+                    end_time=record_data.get("end_time"),
+                )
             )
-        failure = ""
+        failure_list = list()
         if len(test_record.error_record_list) == 0:
             pass
         else:
             for record_data in test_record.error_record_list:
-                failure = "".join(
-                    [
-                        failure,
-                        failure_table.format(
-                            http_method=record_data[0].get("http_method"),
-                            test_url=record_data[0].get("test_url"),
-                            soap=record_data[0].get("soap"),
-                            record_request_info=record_data[0].get("record_request_info"),
-                            clean_record=record_data[0].get("clean_record"),
-                            result_check_dict=record_data[0].get("result_check_dict"),
-                            error=record_data[1]
-                        ),
-                    ]
+                failure_list.append(
+                    failure_table.format(
+                        http_method=record_data[0].get("http_method"),
+                        test_url=record_data[0].get("test_url"),
+                        soap=record_data[0].get("soap"),
+                        record_request_info=record_data[0].get("record_request_info"),
+                        clean_record=record_data[0].get("clean_record"),
+                        result_check_dict=record_data[0].get("result_check_dict"),
+                        error=record_data[1]
+                    ),
                 )
-        new_html_string = html_string.format(success_table=success, failure_table=failure)
         try:
             lock.acquire()
             with open(html_name + ".html", "w+") as file_to_write:
-                file_to_write.write(
-                    new_html_string
+                file_to_write.writelines(
+                    _html_string_head
+                )
+                for success in success_list:
+                    file_to_write.write(success)
+                for failure in failure_list:
+                    file_to_write.write(failure)
+                file_to_write.writelines(
+                    _html_string_bottom
                 )
         except Exception as error:
             print(repr(error), file=sys.stderr)
         finally:
             lock.release()
-    return new_html_string
+    return success_list, failure_list
