@@ -13,6 +13,7 @@ lock = Lock()
 
 def read_action_json(json_file_path: str):
     """
+    read the action json
     :param json_file_path json file's path to read
     """
     try:
@@ -29,6 +30,7 @@ def read_action_json(json_file_path: str):
 
 def write_action_json(json_save_path: str, action_json: list):
     """
+    write action json
     :param json_save_path  json save path
     :param action_json the json str include action to write
     """
